==> common-api-0.0.98-sources.jar: io/aether/api/common/SignHYDROGEN.java <==
package io.aether.api.common;
import java.net.URI;
import java.net.URISyntaxException;
import io.aether.net.fastMeta.FastMetaType;
import java.util.UUID;
import java.util.Date;
import io.aether.net.fastMeta.BytesConverter;
import java.io.Closeable;
import io.aether.net.fastMeta.*;
import io.aether.utils.dataio.DataIn;
import io.aether.utils.dataio.DataOut;
import io.aether.utils.dataio.DataInOutStatic;
import io.aether.utils.dataio.DataInOut;
import it.unimi.dsi.fastutil.objects.ObjectSet;
import it.unimi.dsi.fastutil.bytes.ByteSet;
import it.unimi.dsi.fastutil.doubles.DoubleSet;
import it.unimi.dsi.fastutil.floats.FloatSet;
import it.unimi.dsi.fastutil.ints.IntSet;
import it.unimi.dsi.fastutil.longs.LongSet;
import it.unimi.dsi.fastutil.shorts.ShortSet;
import io.aether.utils.interfaces.AConsumer;
import io.aether.utils.futures.AFuture;
import io.aether.utils.futures.ARFuture;
import java.lang.annotation.*;
import static java.lang.annotation.ElementType.*;
import static java.lang.annotation.RetentionPolicy.*;
import java.util.*;
public class SignHYDROGEN extends Sign implements io.aether.utils.ToString  {
    @Override public int getAetherTypeId() {
        return 2;
        
    }
    public static final FastMetaType<SignHYDROGEN> META_BODY = new FastMetaType<>() {
        @Override public void serialize(FastFutureContext serializeContextVar_146, SignHYDROGEN obj_147, DataOut out_148) {
            if(obj_147.data.length!=64) throw new java.lang.IllegalArgumentException("Array length is bad for obj_147.data=="+obj_147.data.length+" but must be 64");
            out_148.write(obj_147.data);
            
        }
        @Override public SignHYDROGEN deserialize(FastFutureContext serializeContextVar_146, DataIn in_149) {
            byte[] data_150;
            var arraySize_151=64;
            data_150=new byte[arraySize_151];
            in_149.read(data_150);
            return new SignHYDROGEN(data_150);
            
        }
        
    };
    public static final FastMetaType<SignHYDROGEN> META = new FastMetaType<>() {
        @Override public void serialize(FastFutureContext serializeContextVar_152, SignHYDROGEN obj_153, DataOut out_154) {
            SignHYDROGEN.META_BODY.serialize(serializeContextVar_152, obj_153, out_154);
            
        }
        @Override public SignHYDROGEN deserialize(FastFutureContext serializeContextVar_152, DataIn in_155) {
            return SignHYDROGEN.META_BODY.deserialize(serializeContextVar_152, in_155);
            
        }
        
    };
    protected final @L(64) byte[] data;
    public SignHYDROGEN(@L(64) byte[] data)  {
        if (data == null)  {
            throw new java.lang.NullPointerException("Field 'data' cannot be null.");
            
        }
        if (data.length != 64)  {
            throw new java.lang.IllegalArgumentException("Array length for field 'data' must be 64 but was " + data.length);
            
        }
        this.data = data;
        
    }
    public @L(64) byte[] getData()  {
        return this.data;
        
    }
    public boolean dataContains(byte el)  {
        return ByteSet.of(this.data).contains(el);
        
    }
    @Override public boolean equals(Object o)  {
        if (this == o) return true;
        if (o == null || !(o instanceof SignHYDROGEN)) return false;
        SignHYDROGEN that = (SignHYDROGEN) o;
        return java.util.Arrays.equals(this.data, that.data);
        
    }
    @Override public int hashCode()  {
        return java.util.Objects.hash(java.util.Arrays.hashCode(this.data));
        
    }
    @Override public void toString(io.aether.utils.AString sb)  {
        sb.add("SignHYDROGEN(");
        sb.add("data:");
        sb.add(this.data);
        sb.add(')');
        
    }
    
}

==> common-api-0.0.100-sources.jar: io/aether/api/common/SignHYDROGEN.java <==
package io.aether.api.common;
import java.net.URI;
import java.net.URISyntaxException;
import io.aether.net.fastMeta.FastMetaType;
import java.util.UUID;
import java.util.Date;
import io.aether.net.fastMeta.BytesConverter;
import java.io.Closeable;
import io.aether.net.fastMeta.*;
import io.aether.utils.dataio.DataIn;
import io.aether.utils.dataio.DataOut;
import io.aether.utils.dataio.DataInOutStatic;
import io.aether.utils.dataio.DataInOut;
import it.unimi.dsi.fastutil.objects.ObjectSet;
import it.unimi.dsi.fastutil.bytes.ByteSet;
import it.unimi.dsi.fastutil.doubles.DoubleSet;
import it.unimi.dsi.fastutil.floats.FloatSet;
import it.unimi.dsi.fastutil.ints.IntSet;
import it.unimi.dsi.fastutil.longs.LongSet;
import it.unimi.dsi.fastutil.shorts.ShortSet;
import io.aether.utils.interfaces.AConsumer;
import io.aether.utils.futures.AFuture;
import io.aether.utils.futures.ARFuture;
import java.lang.annotation.*;
import static java.lang.annotation.ElementType.*;
import static java.lang.annotation.RetentionPolicy.*;
import java.util.*;
public class SignHYDROGEN extends Sign implements io.aether.utils.ToString  {
    @Override public int getAetherTypeId() {
        return 2;
        
    }
    public static final FastMetaType<SignHYDROGEN> META_BODY = new FastMetaType<>() {
        @Override public void serialize(FastFutureContext serializeContextVar_146, SignHYDROGEN obj_147, DataOut out_148) {
            if(obj_147.data.length!=64) throw new java.lang.IllegalArgumentException("Array length is bad for obj_147.data=="+obj_147.data.length+" but must be 64");
            out_148.write(obj_147.data);
            
        }
        @Override public SignHYDROGEN deserialize(FastFutureContext serializeContextVar_146, DataIn in_149) {
            byte[] data_150;
            var arraySize_151=64;
            data_150=new byte[arraySize_151];
            in_149.read(data_150);
            return new SignHYDROGEN(data_150);
            
        }
        
    };
    public static final FastMetaType<SignHYDROGEN> META = new FastMetaType<>() {
        @Override public void serialize(FastFutureContext serializeContextVar_152, SignHYDROGEN obj_153, DataOut out_154) {
            SignHYDROGEN.META_BODY.serialize(serializeContextVar_152, obj_153, out_154);
            
        }
        @Override public SignHYDROGEN deserialize(FastFutureContext serializeContextVar_152, DataIn in_155) {
            return SignHYDROGEN.META_BODY.deserialize(serializeContextVar_152, in_155);
            
        }
        
    };
    protected final byte[] data;
    public SignHYDROGEN(byte[] data)  {
        if (data == null)  {
            throw new java.lang.NullPointerException("Field 'data' cannot be null.");
            
        }
        if (data.length != 64)  {
            throw new java.lang.IllegalArgumentException("Array length for field 'data' must be 64 but was " + data.length);
            
        }
        this.data = data;
        
    }
    public byte[] getData()  {
        return this.data;
        
    }
    public boolean dataContains(byte el)  {
        return ByteSet.of(this.data).contains(el);
        
    }
    @Override public boolean equals(Object o)  {
        if (this == o) return true;
        if (o == null || !(o instanceof SignHYDROGEN)) return false;
        SignHYDROGEN that = (SignHYDROGEN) o;
        return java.util.Arrays.equals(this.data, that.data);
        
    }
    @Override public int hashCode()  {
        return java.util.Objects.hash(java.util.Arrays.hashCode(this.data));
        
    }
    @Override public String toString()  {
        return toString2();
        
    }
    @Override public void toString(io.aether.utils.AString sb)  {
        sb.add("SignHYDROGEN(");
        sb.add("data:");
        sb.add(this.data);
        sb.add(')');
        
    }
    
}
